# coding: utf-8

from __future__ import print_function
import pytest, py, os, sys
pytest_plugins = "pytester"
from _pytest import pytester
from py.builtin import print_
import codecs
import time

def test_unicode(testdir):
    print(u"file system encoding: %s" % sys.getfilesystemencoding())
    testdir.makepyfile(u"""
        # coding: utf-8
        import pytest
        def test_unicode():
            assert False, u'Ünicode'
    """)
    result = testdir.runpytest()

class MyTmpDir(pytester.TmpTestdir):
    def _run(self, *cmdargs):
        cmdargs = [str(x) for x in cmdargs]
        p1 = self.tmpdir.join("stdout")
        p2 = self.tmpdir.join("stderr")
        print_("running", cmdargs, "curdir=", py.path.local())
        encoding = sys.getfilesystemencoding()
        f1 = codecs.open(str(p1), "w", encoding=encoding)
        f2 = codecs.open(str(p2), "w", encoding=encoding)
        try:
            now = time.time()
            popen = self.popen(cmdargs, stdout=f1, stderr=f2,
                close_fds=(sys.platform != "win32"))
            ret = popen.wait()
        finally:
            f1.close()
            f2.close()
        f1 = codecs.open(str(p1), "r", encoding=encoding)
        f2 = codecs.open(str(p2), "r", encoding=encoding)
        try:
            out = f1.read().splitlines()
            err = f2.read().splitlines()
        finally:
            f1.close()
            f2.close()
        self._dump_lines(out, sys.stdout)
        self._dump_lines(err, sys.stderr)
        return pytester.RunResult(ret, out, err, time.time()-now)

@pytest.fixture
def mytestdir(request):
    return MyTmpDir(request)

def test_unicode_patched(mytestdir):
    print(u"file system encoding: %s" % sys.getfilesystemencoding())
    mytestdir.makepyfile(u"""
        # coding: utf-8
        import pytest
        def test_unicode():
            assert False, u'Ünicode'
    """)
    result = mytestdir.runpytest()
