"""
Tries to build a prototype of the integration test scenario and reuse it.
"""

import pytest
import tempfile
import shutil
import py.path

def test_property_a(scenario):
    """Checks some property given a fresh scenario."""

def test_property_b(scenario):
    """Checks another property given a fresh scenario."""


@pytest.fixture(scope="session")
def scenario_prototype():
    """
    Session scoped prototype for the actual scenario. Should be created
    once and reused for each test.
    """
    tmpdir = py.path.local(tempfile.mkdtemp())
    return ScenarioPrototype(tmpdir.join("prototype"))


@pytest.fixture(scope="function")
def scenario(tmpdir, scenario_prototype):
    return Scenario(tmpdir.join("scenario"), scenario_prototype)


class ScenarioPrototype(object):
    instantiation_count = 0

    def __init__(self, basedir):
        print "Creating scenario prototype in {0}".format(basedir)
        self.basedir = basedir
        basedir.ensure_dir()
        basedir.join("README.txt").write("In this folder the scenario is created, "
                "containing a server and multiple client setups.")
        ScenarioPrototype.instantiation_count += 1
        # The prototype should be only created once for all tests in this module
        assert ScenarioPrototype.instantiation_count <= 1

    def __repr__(self):
        return "<ScenarioPrototype in {0!r}>".format(self.basedir)

    def copy_to(self, target_location):
        shutil.copytree(str(self.basedir.join(".")), str(target_location.join(".")))


class Scenario(object):
    def __init__(self, basedir, prototype):
        print "Creating scenario in {0} from prototype {1}".format(basedir, prototype)
        prototype.copy_to(basedir)
