
class FrozenDict(dict):
    pass

class FrozenOrderedDict(dict):
    pass

def freeze_dict_class( cls ):
    """Makes the given class an immutable dict.

    The following methods raise AttributeError if called:    
    __delitem__
    __setitem__
    clear
    pop
    popitem
    setdefault
    update

    Partically based on the following recipe:
    http://code.activestate.com/recipes/414283-frozen-dictionaries/
    """
    def blocked_attribute( self, *args, **kwargs ):
        raise AttributeError( "A frozendict cannot be modified." )
    for name in ( '__delitem__', '__setitem__', 'clear', 'pop', 'popitem', 'setdefault', 'update' ):
        if hasattr( cls, name ):
            setattr( cls, name, blocked_attribute )
    def __new__(cls, *args, *kwargs):
        new = dict.__new__(cls)
        dict.__init__(new, *args, *kwargs)
        return new
    cls.__new__ = __new__
    return cls
    

freeze_dict_class(FrozenDict)
freeze_dict_class(FrozenOrderedDict)
